@@ -13,6 +13,7 @@ import (
 	"github.com/cloudskiff/driftctl/pkg/memstore"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
 	"github.com/cloudskiff/driftctl/pkg/telemetry"
+	"github.com/cloudskiff/driftctl/pkg/terraform/lock"
 	"github.com/fatih/color"
 	"github.com/mitchellh/go-homedir"
 	"github.com/pkg/errors"
@@ -33,8 +34,7 @@ import (
 	"github.com/cloudskiff/driftctl/pkg/terraform"
 )
 
-func NewScanCmd() *cobra.Command {
-	opts := &pkg.ScanOptions{}
+func NewScanCmd(opts *pkg.ScanOptions) *cobra.Command {
 	opts.BackendOptions = &backend.Options{}
 
 	cmd := &cobra.Command{
@@ -89,6 +89,20 @@ func NewScanCmd() *cobra.Command {
 			}
 			opts.ProviderVersion = providerVersion
 
+			if opts.ProviderVersion == "" {
+				lockfilePath, _ := cmd.Flags().GetString("tf-lockfile")
+
+				// Attempt to read the provider version from a terraform lock file
+				lockFile, err := lock.ReadLocksFromFile(lockfilePath)
+				if err != nil {
+					logrus.WithField("error", err.Error()).Debug("Error while parsing terraform lock file")
+				}
+				if provider := lockFile.GetProviderByAddress(common.RemoteParameter(to).GetProviderAddress()); provider != nil {
+					opts.ProviderVersion = provider.Version
+					logrus.WithFields(logrus.Fields{"version": opts.ProviderVersion, "provider": to}).Debug("Found provider version in terraform lock file")
+				}
+			}
+
 			opts.Quiet, _ = cmd.Flags().GetBool("quiet")
 			opts.DisableTelemetry, _ = cmd.Flags().GetBool("disable-telemetry")
 
@@ -175,6 +189,11 @@ func NewScanCmd() *cobra.Command {
 		".driftignore",
 		"Path to the driftignore file",
 	)
+	fl.String(
+		"tf-lockfile",
+		".terraform.lock.hcl",
+		"Terraform lock file to get the provider's version from. Will be ignored if the file doesn't exist.\n",
+	)
 
 	configDir, err := homedir.Dir()
 	if err != nil {
@@ -224,7 +243,7 @@ func scanRun(opts *pkg.ScanOptions) error {
 
 	scanner := remote.NewScanner(remoteLibrary, alerter, remote.ScannerOptions{Deep: opts.Deep}, driftIgnore)
 
-	iacSupplier, err := supplier.GetIACSupplier(opts.From, providerLibrary, opts.BackendOptions, iacProgress, resFactory, driftIgnore)
+	iacSupplier, err := supplier.GetIACSupplier(opts.From, providerLibrary, opts.BackendOptions, iacProgress, alerter, resFactory, driftIgnore)
 	if err != nil {
 		return err
 	}
@@ -255,6 +274,7 @@ func scanRun(opts *pkg.ScanOptions) error {
 
 	analysis.ProviderVersion = resourceSchemaRepository.ProviderVersion.String()
 	analysis.ProviderName = resourceSchemaRepository.ProviderName
+	store.Bucket(memstore.TelemetryBucket).Set("provider_name", analysis.ProviderName)
 
 	validOutput := false
 	for _, o := range opts.Output {
