@@ -33,6 +33,10 @@ func NewS3Enumerator(config config.SupplierConfig) *S3Enumerator {
 	}
 }
 
+func (s *S3Enumerator) Origin() string {
+	return s.config.String()
+}
+
 func (s *S3Enumerator) Enumerate() ([]string, error) {
 	bucketPath := strings.Split(s.config.Path, "/")
 	if len(bucketPath) < 2 {
