@@ -9,9 +9,14 @@ import (
 
 	"github.com/cloudskiff/driftctl/pkg/filter"
 	"github.com/cloudskiff/driftctl/pkg/output"
+	"github.com/cloudskiff/driftctl/pkg/remote/azurerm"
+	"github.com/cloudskiff/driftctl/pkg/remote/google"
 	resourceaws "github.com/cloudskiff/driftctl/pkg/resource/aws"
+	resourceazure "github.com/cloudskiff/driftctl/pkg/resource/azurerm"
 	resourcegithub "github.com/cloudskiff/driftctl/pkg/resource/github"
+	resourcegoogle "github.com/cloudskiff/driftctl/pkg/resource/google"
 	testresource "github.com/cloudskiff/driftctl/test/resource"
+	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
 	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
 
@@ -144,6 +149,28 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "lambda event source mapping", dirName: "aws_lambda_event_source_mapping", wantErr: false},
 		{name: "VPC", dirName: "vpc", wantErr: false},
 		{name: "Subnet", dirName: "subnet", wantErr: false},
+		{name: "RDS cluster", dirName: "rds_cluster", wantErr: false},
+		{name: "Cloudformation stack", dirName: "cloudformation_stack", wantErr: false},
+		{name: "Api Gateway Rest Api", dirName: "api_gateway_rest_api", wantErr: false},
+		{name: "Api Gateway Account", dirName: "api_gateway_account", wantErr: false},
+		{name: "Api Gateway Api Key", dirName: "api_gateway_api_key", wantErr: false},
+		{name: "Api Gateway authorizer", dirName: "api_gateway_authorizer", wantErr: false},
+		{name: "Api Gateway stage", dirName: "api_gateway_stage", wantErr: false},
+		{name: "Api Gateway resource", dirName: "api_gateway_resource", wantErr: false},
+		{name: "Api Gateway domain name", dirName: "api_gateway_domain_name", wantErr: false},
+		{name: "Api Gateway vpc link", dirName: "api_gateway_vpc_link", wantErr: false},
+		{name: "Api Gateway request validator", dirName: "api_gateway_request_validator", wantErr: false},
+		{name: "Api Gateway rest api policy", dirName: "api_gateway_rest_api_policy", wantErr: false},
+		{name: "Api Gateway base path mapping", dirName: "api_gateway_base_path_mapping", wantErr: false},
+		{name: "Api Gateway method", dirName: "api_gateway_method", wantErr: false},
+		{name: "Api Gateway model", dirName: "api_gateway_model", wantErr: false},
+		{name: "Api Gateway method response", dirName: "api_gateway_method_response", wantErr: false},
+		{name: "AppAutoScaling Targets", dirName: "aws_appautoscaling_target", wantErr: false},
+		{name: "network acl", dirName: "aws_network_acl", wantErr: false},
+		{name: "network acl rule", dirName: "aws_network_acl_rule", wantErr: false},
+		{name: "default network acl", dirName: "aws_default_network_acl", wantErr: false},
+		{name: "App autoscaling policy", dirName: "aws_appautoscaling_policy", wantErr: false},
+		{name: "App autoscaling scheduled action", dirName: "aws_appautoscaling_scheduled_action", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -302,6 +329,187 @@ func TestTerraformStateReader_Github_Resources(t *testing.T) {
 	}
 }
 
+func TestTerraformStateReader_Google_Resources(t *testing.T) {
+	tests := []struct {
+		name    string
+		dirName string
+		wantErr bool
+	}{
+		{name: "compute firewall", dirName: "google_compute_firewall", wantErr: false},
+		{name: "compute router", dirName: "google_compute_router", wantErr: false},
+		{name: "compute instance", dirName: "google_compute_instance", wantErr: false},
+		{name: "Bucket IAM Bindings", dirName: "google_bucket_iam_binding", wantErr: false},
+		{name: "Bucket IAM members", dirName: "google_bucket_iam_member", wantErr: false},
+		{name: "Bucket IAM Policy", dirName: "google_bucket_iam_policy", wantErr: false},
+		{name: "DNS managed zone", dirName: "google_dns_managed_zone", wantErr: false},
+		{name: "bigquery dataset", dirName: "google_bigquery_dataset", wantErr: false},
+		{name: "bigquery table", dirName: "google_bigquery_table", wantErr: false},
+		{name: "compute address", dirName: "google_compute_address", wantErr: false},
+		{name: "cloudfunctions function", dirName: "google_cloudfunctions_function", wantErr: false},
+		{name: "compute subnetwork", dirName: "google_compute_subnetwork", wantErr: false},
+		{name: "compute disk", dirName: "google_compute_disk", wantErr: false},
+		{name: "bigtable instance", dirName: "google_bigtable_instance", wantErr: false},
+		{name: "bigtable table", dirName: "google_bigtable_table", wantErr: false},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			progress := &output.MockProgress{}
+			progress.On("Inc").Return().Times(1)
+			progress.On("Stop").Return().Times(1)
+
+			shouldUpdate := tt.dirName == *goldenfile.Update
+
+			var realProvider *google.GCPTerraformProvider
+			providerVersion := "3.78.0"
+			var err error
+			realProvider, err = google.NewGCPTerraformProvider(providerVersion, progress, "")
+			if err != nil {
+				t.Fatal(err)
+			}
+			provider := terraform2.NewFakeTerraformProvider(realProvider)
+
+			if shouldUpdate {
+				err = realProvider.Init()
+				if err != nil {
+					t.Fatal(err)
+				}
+				provider.ShouldUpdate()
+			}
+
+			library := terraform.NewProviderLibrary()
+			library.AddProvider(terraform.GOOGLE, provider)
+
+			repo := testresource.InitFakeSchemaRepository(terraform.GOOGLE, providerVersion)
+			resourcegoogle.InitResourcesMetadata(repo)
+			factory := terraform.NewTerraformResourceFactory(repo)
+
+			r := &TerraformStateReader{
+				config: config.SupplierConfig{
+					Path: path.Join(goldenfile.GoldenFilePath, tt.dirName, "terraform.tfstate"),
+				},
+				library:      library,
+				progress:     progress,
+				deserializer: resource.NewDeserializer(factory),
+			}
+
+			got, err := r.Resources()
+			resGoldenName := goldenfile.ResultsFilename
+			if shouldUpdate {
+				unm, err := json.Marshal(got)
+				if err != nil {
+					panic(err)
+				}
+				goldenfile.WriteFile(tt.dirName, unm, resGoldenName)
+			}
+
+			file := goldenfile.ReadFile(tt.dirName, resGoldenName)
+			var want []interface{}
+			if err := json.Unmarshal(file, &want); err != nil {
+				panic(err)
+			}
+
+			if (err != nil) != tt.wantErr {
+				t.Errorf("Resources() error = %v, wantErr %v", err, tt.wantErr)
+				return
+			}
+			changelog, err := diff.Diff(convert(got), want)
+			if err != nil {
+				panic(err)
+			}
+			if len(changelog) > 0 {
+				for _, change := range changelog {
+					t.Errorf("%s got = %v, want %v", strings.Join(change.Path, "."), change.From, change.To)
+				}
+			}
+		})
+	}
+}
+
+func TestTerraformStateReader_Azure_Resources(t *testing.T) {
+	tests := []struct {
+		name    string
+		dirName string
+		wantErr bool
+	}{
+		{name: "network security group", dirName: "azurerm_network_security_group", wantErr: false},
+		{name: "load balancers", dirName: "azurerm_lb", wantErr: false},
+		{name: "private dns zone", dirName: "azurerm_private_dns_zone", wantErr: false},
+		{name: "images", dirName: "azurerm_image", wantErr: false},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			progress := &output.MockProgress{}
+			progress.On("Inc").Return().Times(1)
+			progress.On("Stop").Return().Times(1)
+
+			shouldUpdate := tt.dirName == *goldenfile.Update
+
+			var realProvider *azurerm.AzureTerraformProvider
+			providerVersion := "2.71.0"
+			var err error
+			realProvider, err = azurerm.NewAzureTerraformProvider(providerVersion, progress, "")
+			if err != nil {
+				t.Fatal(err)
+			}
+			provider := terraform2.NewFakeTerraformProvider(realProvider)
+
+			if shouldUpdate {
+				err = realProvider.Init()
+				if err != nil {
+					t.Fatal(err)
+				}
+				provider.ShouldUpdate()
+			}
+
+			library := terraform.NewProviderLibrary()
+			library.AddProvider(terraform.AZURE, provider)
+
+			repo := testresource.InitFakeSchemaRepository(terraform.AZURE, providerVersion)
+			resourceazure.InitResourcesMetadata(repo)
+			factory := terraform.NewTerraformResourceFactory(repo)
+
+			r := &TerraformStateReader{
+				config: config.SupplierConfig{
+					Path: path.Join(goldenfile.GoldenFilePath, tt.dirName, "terraform.tfstate"),
+				},
+				library:      library,
+				progress:     progress,
+				deserializer: resource.NewDeserializer(factory),
+			}
+
+			got, err := r.Resources()
+			resGoldenName := goldenfile.ResultsFilename
+			if shouldUpdate {
+				unm, err := json.Marshal(got)
+				if err != nil {
+					panic(err)
+				}
+				goldenfile.WriteFile(tt.dirName, unm, resGoldenName)
+			}
+
+			file := goldenfile.ReadFile(tt.dirName, resGoldenName)
+			var want []interface{}
+			if err := json.Unmarshal(file, &want); err != nil {
+				panic(err)
+			}
+
+			if (err != nil) != tt.wantErr {
+				t.Errorf("Resources() error = %v, wantErr %v", err, tt.wantErr)
+				return
+			}
+			changelog, err := diff.Diff(convert(got), want)
+			if err != nil {
+				panic(err)
+			}
+			if len(changelog) > 0 {
+				for _, change := range changelog {
+					t.Errorf("%s got = %v, want %v", strings.Join(change.Path, "."), change.From, change.To)
+				}
+			}
+		})
+	}
+}
+
 func convert(got []*resource.Resource) []interface{} {
 	unm, err := json.Marshal(got)
 	if err != nil {
