@@ -14,21 +14,21 @@ func NewAwsDefaultSubnet() AwsDefaultSubnet {
 	return AwsDefaultSubnet{}
 }
 
-func (m AwsDefaultSubnet) Execute(remoteResources, resourcesFromState *[]resource.Resource) error {
+func (m AwsDefaultSubnet) Execute(remoteResources, resourcesFromState *[]*resource.Resource) error {
 
-	newRemoteResources := make([]resource.Resource, 0)
+	newRemoteResources := make([]*resource.Resource, 0)
 
 	for _, remoteResource := range *remoteResources {
 		existInState := false
 
 		// Ignore all resources other than default Subnet
-		if remoteResource.TerraformType() != aws.AwsDefaultSubnetResourceType {
+		if remoteResource.ResourceType() != aws.AwsDefaultSubnetResourceType {
 			newRemoteResources = append(newRemoteResources, remoteResource)
 			continue
 		}
 
 		for _, stateResource := range *resourcesFromState {
-			if resource.IsSameResource(remoteResource, stateResource) {
+			if remoteResource.Equal(stateResource) {
 				existInState = true
 				break
 			}
@@ -40,8 +40,8 @@ func (m AwsDefaultSubnet) Execute(remoteResources, resourcesFromState *[]resourc
 
 		if !existInState {
 			logrus.WithFields(logrus.Fields{
-				"id":   remoteResource.TerraformId(),
-				"type": remoteResource.TerraformType(),
+				"id":   remoteResource.ResourceId(),
+				"type": remoteResource.ResourceType(),
 			}).Debug("Ignoring default Subnet as it is not managed by IaC")
 		}
 
