@@ -19,27 +19,25 @@ func NewRoute53RecordIDReconcilier() Route53RecordIDReconcilier {
 	return Route53RecordIDReconcilier{}
 }
 
-func (m Route53RecordIDReconcilier) Execute(_, resourcesFromState *[]resource.Resource) error {
+func (m Route53RecordIDReconcilier) Execute(_, resourcesFromState *[]*resource.Resource) error {
 
 	for _, stateResource := range *resourcesFromState {
 
-		if stateResource.TerraformType() != aws.AwsRoute53RecordResourceType {
+		if stateResource.ResourceType() != aws.AwsRoute53RecordResourceType {
 			continue
 		}
 
-		record, _ := stateResource.(*resource.AbstractResource)
-
 		vars := []string{
-			(*record.Attrs)["zone_id"].(string),
-			(*record.Attrs)["fqdn"].(string),
-			(*record.Attrs)["type"].(string),
+			(*stateResource.Attrs)["zone_id"].(string),
+			(*stateResource.Attrs)["fqdn"].(string),
+			(*stateResource.Attrs)["type"].(string),
 		}
 		newId := strings.Join(vars, "_")
-		if newId != record.Id {
-			record.Id = newId
-			_ = record.Attrs.SafeSet([]string{"id"}, newId)
+		if newId != stateResource.Id {
+			stateResource.Id = newId
+			_ = stateResource.Attrs.SafeSet([]string{"id"}, newId)
 			logrus.WithFields(logrus.Fields{
-				"old_id": record.TerraformId(),
+				"old_id": stateResource.ResourceId(),
 				"new_id": newId,
 			}).Debug("Normalized route53 record ID")
 		}
