@@ -23,13 +23,13 @@ func (e *EC2InstanceEnumerator) SupportedType() resource.ResourceType {
 	return aws.AwsInstanceResourceType
 }
 
-func (e *EC2InstanceEnumerator) Enumerate() ([]resource.Resource, error) {
+func (e *EC2InstanceEnumerator) Enumerate() ([]*resource.Resource, error) {
 	instances, err := e.repository.ListAllInstances()
 	if err != nil {
 		return nil, remoteerror.NewResourceListingError(err, string(e.SupportedType()))
 	}
 
-	results := make([]resource.Resource, len(instances))
+	results := make([]*resource.Resource, len(instances))
 
 	for _, instance := range instances {
 		results = append(
