@@ -9,11 +9,14 @@ import (
 	"github.com/aws/aws-sdk-go/service/lambda"
 	"github.com/cloudskiff/driftctl/mocks"
 	"github.com/cloudskiff/driftctl/pkg/filter"
+	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws"
 	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
+	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
 	testresource "github.com/cloudskiff/driftctl/test/resource"
 	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
+	"github.com/pkg/errors"
 	"github.com/stretchr/testify/mock"
 
 	"github.com/cloudskiff/driftctl/pkg/remote/aws/repository"
@@ -31,13 +34,13 @@ func TestScanLambdaFunction(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockLambdaRepository)
+		mocks   func(*repository.MockLambdaRepository, *mocks.AlerterInterface)
 		err     error
 	}{
 		{
 			test:    "no lambda functions",
 			dirName: "lambda_function_empty",
-			mocks: func(repo *repository.MockLambdaRepository) {
+			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllLambdaFunctions").Return([]*lambda.FunctionConfiguration{}, nil)
 			},
 			err: nil,
@@ -45,7 +48,7 @@ func TestScanLambdaFunction(t *testing.T) {
 		{
 			test:    "with lambda functions",
 			dirName: "lambda_function_multiple",
-			mocks: func(repo *repository.MockLambdaRepository) {
+			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllLambdaFunctions").Return([]*lambda.FunctionConfiguration{
 					{
 						FunctionName: awssdk.String("foo"),
@@ -60,7 +63,7 @@ func TestScanLambdaFunction(t *testing.T) {
 		{
 			test:    "One lambda with signing",
 			dirName: "lambda_function_signed",
-			mocks: func(repo *repository.MockLambdaRepository) {
+			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllLambdaFunctions").Return([]*lambda.FunctionConfiguration{
 					{
 						FunctionName: awssdk.String("foo"),
@@ -72,8 +75,11 @@ func TestScanLambdaFunction(t *testing.T) {
 		{
 			test:    "cannot list lambda functions",
 			dirName: "lambda_function_empty",
-			mocks: func(repo *repository.MockLambdaRepository) {
-				repo.On("ListAllLambdaFunctions").Return([]*lambda.FunctionConfiguration{}, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllLambdaFunctions").Return([]*lambda.FunctionConfiguration{}, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsLambdaFunctionResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsLambdaFunctionResourceType, resourceaws.AwsLambdaFunctionResourceType), alerts.EnumerationPhase)).Return()
 			},
 			err: nil,
 		},
@@ -92,16 +98,15 @@ func TestScanLambdaFunction(t *testing.T) {
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
-			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
-
 			scanOptions := ScannerOptions{Deep: true}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
 			// Initialize mocks
+			alerter := &mocks.AlerterInterface{}
 			fakeRepo := &repository.MockLambdaRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.LambdaRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -122,7 +127,7 @@ func TestScanLambdaFunction(t *testing.T) {
 			}
 
 			remoteLibrary.AddEnumerator(aws.NewLambdaFunctionEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsLambdaFunctionResourceType, aws.NewLambdaFunctionDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsLambdaFunctionResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsLambdaFunctionResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -134,6 +139,8 @@ func TestScanLambdaFunction(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsLambdaFunctionResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -143,13 +150,13 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 	tests := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockLambdaRepository)
+		mocks   func(*repository.MockLambdaRepository, *mocks.AlerterInterface)
 		err     error
 	}{
 		{
 			test:    "no EventSourceMapping",
 			dirName: "lambda_source_mapping_empty",
-			mocks: func(repo *repository.MockLambdaRepository) {
+			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllLambdaEventSourceMappings").Return([]*lambda.EventSourceMappingConfiguration{}, nil)
 			},
 			err: nil,
@@ -157,7 +164,7 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 		{
 			test:    "with 2 sqs EventSourceMapping",
 			dirName: "lambda_source_mapping_sqs_multiple",
-			mocks: func(repo *repository.MockLambdaRepository) {
+			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllLambdaEventSourceMappings").Return([]*lambda.EventSourceMappingConfiguration{
 					{
 						UUID: awssdk.String("13ff66f8-37eb-4ad6-a0a8-594fea72df4f"),
@@ -172,7 +179,7 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 		{
 			test:    "with dynamo EventSourceMapping",
 			dirName: "lambda_source_mapping_dynamo_multiple",
-			mocks: func(repo *repository.MockLambdaRepository) {
+			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllLambdaEventSourceMappings").Return([]*lambda.EventSourceMappingConfiguration{
 					{
 						UUID: awssdk.String("1aa9c4a0-060b-41c1-a9ae-dc304ebcdb00"),
@@ -184,8 +191,11 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 		{
 			test:    "cannot list lambda functions",
 			dirName: "lambda_function_empty",
-			mocks: func(repo *repository.MockLambdaRepository) {
-				repo.On("ListAllLambdaEventSourceMappings").Return([]*lambda.EventSourceMappingConfiguration{}, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockLambdaRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllLambdaEventSourceMappings").Return([]*lambda.EventSourceMappingConfiguration{}, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsLambdaEventSourceMappingResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsLambdaEventSourceMappingResourceType, resourceaws.AwsLambdaEventSourceMappingResourceType), alerts.EnumerationPhase)).Return()
 			},
 			err: nil,
 		},
@@ -204,16 +214,15 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 				SharedConfigState: session.SharedConfigEnable,
 			}))
 
-			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
-
 			scanOptions := ScannerOptions{Deep: true}
 			providerLibrary := terraform.NewProviderLibrary()
 			remoteLibrary := common.NewRemoteLibrary()
 
 			// Initialize mocks
+			alerter := &mocks.AlerterInterface{}
 			fakeRepo := &repository.MockLambdaRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.LambdaRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -246,6 +255,8 @@ func TestScanLambdaEventSourceMapping(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsLambdaEventSourceMappingResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
