@@ -16,7 +16,7 @@ func TestAcc_AwsSNSTopicPolicy(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_sns_topic_policy"},
-		Args:             []string{"scan", "--filter", "Type=='aws_sns_topic' || Type=='aws_sns_topic_policy'", "--deep"},
+		Args:             []string{"scan", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
