@@ -26,7 +26,7 @@ func TestAcc_AwsSNSTopic(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_sns_topic"},
-		Args:             []string{"scan", "--filter", "Type=='aws_sns_topic'", "--deep"},
+		Args:             []string{"scan", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
