@@ -24,7 +24,7 @@ func TestAcc_AwsSQSQueue(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_sqs_queue"},
-		Args:             []string{"scan", "--filter", "Type=='aws_sqs_queue'", "--deep"},
+		Args:             []string{"scan", "--deep"},
 		Checks: []acceptance.AccCheck{
 			{
 				Env: map[string]string{
